/*
 * Licensed to Elasticsearch under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.index.fielddata;

import org.apache.lucene.index.NumericDocValues;
import org.apache.lucene.util.NumericUtils;

import java.io.IOException;

/**
 * {@link NumericDocValues} instance that wraps a {@link NumericDoubleValues}
 * and converts the doubles to sortable long bits using
 * {@link NumericUtils#doubleToSortableLong(double)}.
 */
final class SortableLongBitsNumericDocValues extends AbstractNumericDocValues {

    private int docID = -1;
    private final NumericDoubleValues values;

    SortableLongBitsNumericDocValues(NumericDoubleValues values) {
        this.values = values;
    }

    @Override
    public long longValue() throws IOException {
        return NumericUtils.doubleToSortableLong(values.doubleValue());
    }

    @Override
    public boolean advanceExact(int target) throws IOException {
        docID = target;
        return values.advanceExact(target);
    }

    @Override
    public int docID() {
        return docID;
    }

    /** Return the wrapped values. */
    public NumericDoubleValues getDoubleValues() {
        return values;
    }

}
