/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License;
 * you may not use this file except in compliance with the Elastic License.
 */
package org.elasticsearch.xpack.core.ml.action;

import org.elasticsearch.common.io.stream.NamedWriteableRegistry;
import org.elasticsearch.common.settings.Settings;
import org.elasticsearch.search.SearchModule;
import org.elasticsearch.test.AbstractStreamableTestCase;
import org.elasticsearch.xpack.core.ml.action.PutDatafeedAction.Response;
import org.elasticsearch.xpack.core.ml.datafeed.DatafeedConfig;
import org.elasticsearch.xpack.core.ml.datafeed.DatafeedConfigTests;

import java.util.Arrays;
import java.util.Collections;

public class PutDatafeedActionResponseTests extends AbstractStreamableTestCase<Response> {

    @Override
    protected Response createTestInstance() {
        DatafeedConfig.Builder datafeedConfig = new DatafeedConfig.Builder(
                DatafeedConfigTests.randomValidDatafeedId(), randomAlphaOfLength(10));
        datafeedConfig.setIndices(Arrays.asList(randomAlphaOfLength(10)));
        datafeedConfig.setTypes(Arrays.asList(randomAlphaOfLength(10)));
        return new Response(datafeedConfig.build());
    }

    @Override
    protected Response createBlankInstance() {
        return new Response();
    }

    @Override
    protected NamedWriteableRegistry getNamedWriteableRegistry() {
        SearchModule searchModule = new SearchModule(Settings.EMPTY, false, Collections.emptyList());
        return new NamedWriteableRegistry(searchModule.getNamedWriteables());
    }
}
